@@ -1,10 +1,10 @@
 package Perinci::Object;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 require Exporter;
 our @ISA    = qw(Exporter);
@@ -43,17 +43,19 @@ sub riresmeta {
 1;
 # ABSTRACT: Object-oriented interface for Rinci metadata
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Perinci::Object - Object-oriented interface for Rinci metadata
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -133,24 +135,42 @@ Exported by default. A shortcut for Perinci::Object::variable->new($meta).
 
 Exported by default. A shortcut for Perinci::Object::package->new($meta).
 
-=head2 rires $res => OBJECT
+=head2 riresmeta $res => OBJECT
 
 Exported by default. A shortcut for Perinci::Object::Result->new($res).
 
+
+None are exported by default, but they are exportable.
+
 =head1 SEE ALSO
 
 L<Rinci>
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Object>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Object>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Object>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
